library(shiny)
library(dplyr)
prenoms=readRDS("data/prenoms.RDS")
library(ggplot2)

f_name_years=function(prenom,annee_min,annee_max,par_departement=FALSE){
  name_years=prenoms %>% 
    filter(name==prenom,
           year>=annee_min,
           year<=annee_max)
  if(!par_departement){ 
    name_years=name_years %>% 
      group_by(year) %>% 
      summarise(n=n(),.groups = 'drop')
  }
  return(name_years)
}

ui <- fluidPage(
  wellPanel(
    textInput(inputId="prenom",
              label="Quel est ton prénom?",
              value="Lise"),   
    sliderInput("minmax_year",
                "années min et max",
                min=1900,
                max=2018,
                value=c(1900,2018))
  ), #wellPanel
  fluidRow(
    column(width=4,
           dataTableOutput("table_name_years")
    ),#column
    column(width=8,
           tabsetPanel(
             tabPanel("France",
             plotOutput("plot_name_years")
           ),#tabPanel
           tabPanel("Par dép.",
                    plotOutput("plot_name_years_dep")
           )#tabPanel
    )#tabsetPanel
  )#column
)#fluidRow
)

server <- function(input, output) {
  
  r_name_years=reactive({
    print("calcul de name_years")
    f_name_years(input$prenom,
                 input$minmax_year[1],
                 input$minmax_year[2])
  })
  
  output$table_name_years <- renderDataTable({
    name_years=r_name_years()
  })
  output$plot_name_years <- renderPlot({
    name_years=r_name_years()
    ggplot(name_years,aes(x=year,y=n)) +
      geom_line()+
      labs(title=paste("Occurences du prénom '",
                       input$prenom,
                       "' par année"))
    
  })
  output$plot_name_years_dep <- renderPlot({
    name_years_dep= f_name_years(input$prenom,
                                 input$minmax_year[1],
                                 input$minmax_year[2],
                                 par_departement=TRUE) 
    ggplot(name_years_dep,aes(x=year,y=n, color=dpt)) +
      geom_line()+
      labs(title=paste("Occurences du prénom '",
                       input$prenom,
                       "' par année et par département"))
    
  })
}

shinyApp(ui = ui, server = server)